=============
Miscellaneous
=============

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    DataFrame.apply
    DataFrame.corr
    DataFrame.frame_equal
    DataFrame.lazy
    DataFrame.map_rows
